class PeopleController < ApplicationController
  before_action :set_person, only: %i[ show edit update destroy download add_friend remove_friend ]

  # GET /people or /people.json
  def index
    @people = Person.get_page(params[:page])
  end

  # GET /people/1 or /people/1.json
  def show
    @comments = @person.comments
  end

  # GET /people/new
  def new
    @person = Person.new
  end

  # GET /people/1/edit
  def edit
  end

  # POST /people or /people.json
  def create
    @person = Person.new(person_params)

    respond_to do |format|
      #Attachment.save_file params[:person][:attachment], @person
      if @person.save
        format.html { redirect_to person_url(@person), notice: "Person was successfully created." }
        format.json { render :show, status: :created, location: @person }
      else
        format.html { render :new, status: :unprocessable_entity }
        format.json { render json: @person.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /people/1 or /people/1.json
  def update
    respond_to do |format|
      #Attachment.save_file params[:person][:attachment], @person
      if @person.update(person_params)
        format.html { redirect_to person_url(@person), notice: "Person was successfully updated." }
        format.json { render :show, status: :ok, location: @person }
      else
        format.html { render :edit, status: :unprocessable_entity }
        format.json { render json: @person.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /people/1 or /people/1.json
  def destroy
    @person.destroy

    respond_to do |format|
      format.html { redirect_to people_url, notice: "Person was successfully destroyed." }
      format.json { head :no_content }
    end
  end

  def download
    a = @person.attachment
    unless a.nil?
      send_file a.path, type: a.mime, filename: a.name, disposition: :inline
      return
    end
    head 404
  end

  def add_friend
    my_user = @person.user
    if @user != my_user
      @user.friends << my_user
      my_user.friends << @user
    end
    redirect_back fallback_location: hello_path
  end

  def remove_friend
    @user.friends.delete(@person.user)
    @person.user.friends.delete(@user)
    redirect_back fallback_location: hello_path
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_person
      @person = Person.find(params[:id])
    end

    # Only allow a list of trusted parameters through.
    def person_params
      params.require(:person).permit(:name, :birthdate, :gender, :into, :uploaded_image)
    end
end
