class User < ApplicationRecord
  attr_accessor :password
  before_save :encrypt_password

  has_one :person
  has_many :comments
  has_many :people, through: :comments
  has_and_belongs_to_many :friends, class_name: 'User', foreign_key: 'friend_id', join_table: 'friends_users', association_foreign_key: 'user_id'

  validates :username, presence: true
  validates :email, { presence: true, uniqueness: true }
  validates :password, confirmation: true, if: :password_required?

  def self.encrypt(pass, salt)
    Digest::SHA1.hexdigest pass+salt
  end

  def encrypt_password
    return if self.password.blank?
    if self.new_record?
      self.salt = SecureRandom.base64 16
    end
    self.encrypted_password = User.encrypt(password, salt)
  end

  def self.authenticate(email, password)
    user = User.where(email: email).take
    user && user.authenticated?(password) ? user : nil
  end

  def authenticated?(pass)
    self.encrypted_password == User.encrypt(pass, self.salt)
  end

  def password_required?
    self.new_record? || !self.password.blank?
  end
end
